@@ -11,9 +11,10 @@ import requests
 from cpg_utils.cloud import get_google_identity_token
 from analysis_runner.constants import get_server_endpoint, SERVER_ENDPOINT
 from analysis_runner.cromwell_model import WorkflowMetadataModel
-from analysis_runner.git import (
+from cpg_utils.git import (
     get_git_default_remote,
     get_git_commit_ref_of_current_repository,
+    get_organisation_name_from_remote,
     get_repo_name_from_remote,
     get_relative_path_from_git_root,
     check_if_commit_is_on_remote,
@@ -185,7 +186,8 @@ def _run_cromwell(
     _cwd = cwd
 
     if repository is None:
-        _repository = get_repo_name_from_remote(get_git_default_remote())
+        remote = get_git_default_remote()
+        _repository = f'{get_organisation_name_from_remote(remote)}/{get_repo_name_from_remote(remote)}'
         if _commit_ref is None:
             _commit_ref = get_git_commit_ref_of_current_repository()
 
